@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_SCANNERPARSER_H_INCLUDED
 # define YY_YY_SCANNERPARSER_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,78 +40,77 @@
 extern int yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     IDENTIFIER = 258,
-     TYPEDEF_NAME = 259,
-     INTEGER = 260,
-     FLOATING = 261,
-     CHARACTER = 262,
-     STRING = 263,
-     ELLIPSIS = 264,
-     ADDEQ = 265,
-     SUBEQ = 266,
-     MULEQ = 267,
-     DIVEQ = 268,
-     MODEQ = 269,
-     XOREQ = 270,
-     ANDEQ = 271,
-     OREQ = 272,
-     SL = 273,
-     SR = 274,
-     SLEQ = 275,
-     SREQ = 276,
-     EQ = 277,
-     NOTEQ = 278,
-     LTEQ = 279,
-     GTEQ = 280,
-     ANDAND = 281,
-     OROR = 282,
-     PLUSPLUS = 283,
-     MINUSMINUS = 284,
-     ARROW = 285,
-     AUTO = 286,
-     BOOL = 287,
-     BREAK = 288,
-     CASE = 289,
-     CHAR = 290,
-     CONST = 291,
-     CONTINUE = 292,
-     DEFAULT = 293,
-     DO = 294,
-     DOUBLE = 295,
-     ELSE = 296,
-     ENUM = 297,
-     EXTERN = 298,
-     FLOAT = 299,
-     FOR = 300,
-     GOTO = 301,
-     IF = 302,
-     INLINE = 303,
-     INT = 304,
-     LONG = 305,
-     REGISTER = 306,
-     RESTRICT = 307,
-     RETURN = 308,
-     SHORT = 309,
-     SIGNED = 310,
-     SIZEOF = 311,
-     STATIC = 312,
-     STRUCT = 313,
-     SWITCH = 314,
-     TYPEDEF = 315,
-     UNION = 316,
-     UNSIGNED = 317,
-     VOID = 318,
-     VOLATILE = 319,
-     WHILE = 320,
-     FUNCTION_MACRO = 321,
-     OBJECT_MACRO = 322
-   };
+  enum yytokentype
+  {
+    IDENTIFIER = 258,
+    TYPEDEF_NAME = 259,
+    INTEGER = 260,
+    FLOATING = 261,
+    CHARACTER = 262,
+    STRING = 263,
+    ELLIPSIS = 264,
+    ADDEQ = 265,
+    SUBEQ = 266,
+    MULEQ = 267,
+    DIVEQ = 268,
+    MODEQ = 269,
+    XOREQ = 270,
+    ANDEQ = 271,
+    OREQ = 272,
+    SL = 273,
+    SR = 274,
+    SLEQ = 275,
+    SREQ = 276,
+    EQ = 277,
+    NOTEQ = 278,
+    LTEQ = 279,
+    GTEQ = 280,
+    ANDAND = 281,
+    OROR = 282,
+    PLUSPLUS = 283,
+    MINUSMINUS = 284,
+    ARROW = 285,
+    AUTO = 286,
+    BOOL = 287,
+    BREAK = 288,
+    CASE = 289,
+    CHAR = 290,
+    CONST = 291,
+    CONTINUE = 292,
+    DEFAULT = 293,
+    DO = 294,
+    DOUBLE = 295,
+    ELSE = 296,
+    ENUM = 297,
+    EXTERN = 298,
+    FLOAT = 299,
+    FOR = 300,
+    GOTO = 301,
+    IF = 302,
+    INLINE = 303,
+    INT = 304,
+    LONG = 305,
+    REGISTER = 306,
+    RESTRICT = 307,
+    RETURN = 308,
+    SHORT = 309,
+    SIGNED = 310,
+    SIZEOF = 311,
+    STATIC = 312,
+    STRUCT = 313,
+    SWITCH = 314,
+    TYPEDEF = 315,
+    UNION = 316,
+    UNSIGNED = 317,
+    VOID = 318,
+    VOLATILE = 319,
+    WHILE = 320,
+    FUNCTION_MACRO = 321,
+    OBJECT_MACRO = 322
+  };
 #endif
 /* Tokens.  */
 #define IDENTIFIER 258
@@ -180,13 +179,12 @@ extern int yydebug;
 #define FUNCTION_MACRO 321
 #define OBJECT_MACRO 322
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-/* Line 2058 of yacc.c  */
-#line 190 "scannerparser.y"
+#line 190 "scannerparser.y" /* yacc.c:1909  */
 
   char *str;
   GList *list;
@@ -197,29 +195,15 @@ typedef union YYSTYPE
   FunctionSpecifier function_specifier;
   UnaryOperator unary_operator;
 
-
-/* Line 2058 of yacc.c  */
-#line 203 "scannerparser.h"
-} YYSTYPE;
+#line 199 "scannerparser.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int yyparse (GIGenerator* igenerator);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_SCANNERPARSER_H_INCLUDED  */
